import { useState, useEffect } from 'react';
import { getGzhAccountOptionsApi } from '@src/http/api';
import request from '@src/http/index';

interface Account {
  id: string;
  name: string;
  // Add other account properties as needed
}

export const useAccountOptions = () => {
  const [accountOptions, setAccountOptions] = useState<Account[]>([]);
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState<string | null>(null);

  const getAccountList = async ({accountType}: {accountType?: string}) => {
    try {
      setLoading(true);
      setError(null);
			const data = await request.get(getGzhAccountOptionsApi, {
				params: {
					accountType
				}
			});
      setAccountOptions(data.data as Account[]);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to fetch accounts');
    } finally {
      setLoading(false);
    }
  };

  return {
    accountOptions,
    getAccountList,
    loading,
    error
  };
}; 
